@@ -8,7 +8,7 @@ class ShellCommandFailedError(Exception):
     retcode = property(lambda self: self.__retcode)
     
     def __init__(self, cmd, retcode):
-        ShellCommandFailedError.__init__(self, "command '%s' failed with status %s" % (cmd, retcode))
+        Exception.__init__(self, "command '%s' failed with status %s" % (cmd, retcode))
         self.__retcode = retcode
 
 
